@@ -1,5 +1,5 @@
 rm Makefile
 rm src/Makefile
-/opt/qt4-maemo5/bin/qmake-qt4
+/usr/bin/qmake-qt4
 make clean
 make
