@@ -24,6 +24,9 @@
 #include "symfoniefullscreenexitbutton.h"
 #include "symfonieoptionsdialog.h"
 #include "symfonievolumeslider.h"
+#include "symfonievolumedialog.h"
+#include "symfonieseekslider.h"
+#include "symfonielabelignoreevent.h"
 
 
 MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWidget *parent) :
@@ -33,11 +36,13 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
         timerWindow(NULL),
         fileTypesDialog(NULL),
         optionsDialog(NULL),
+        volumeDialog(NULL),
         player(player),
         equalizerWindow(new SymfonieEqualizerWindow(this)),
         currentOrientationMode(Qt::WA_Maemo5LandscapeOrientation),
         isInPortait(false),
-        isResumePlayback(false)
+        isResumePlayback(false),
+        isMainToolbarVisible(false)
 {
     this->setAttribute(Qt::WA_Maemo5StackedWindow);
     ui->setupUi(this);
@@ -125,15 +130,16 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     //this->ui->fileListWidget->setItemDelegate(new SymfonieRichTextDelegate());
 
-    this->seekSlider = new Phonon::SeekSlider();
+    this->seekSlider = new SymfonieSeekSlider(this);
     this->seekSlider->setMediaObject(player->getMediaObject());
 
     this->ui->sliderPanel->layout()->addWidget(this->seekSlider);
+    SymfonieLabelIgnoreEvent *l = new SymfonieLabelIgnoreEvent(this);
+    this->ui->sliderPanel->layout()->addWidget(l);
 
 
 
 
-    this->volumeSlider = new SymfonieVolumeSlider(this->getPlayer()->getAudioOutput(), this);
     //this->volumeSlider->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::Maximum);
 
 
@@ -144,12 +150,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
     this->fullScreenExitButton = new SymfonieFullScreenExitButton(this);
 
-    this->ui->sliderLabel->setParent(this);
-    this->seekSlider->installEventFilter(this->ui->sliderLabel);
 
-    //button2  = new QPushButton("Click here to open another stacked window", this);
-    // button2->setAttribute(Qt::WA_Maemo5StackedWindow);
-    //  button2->setWindowFlags(button2->windowFlags() | Qt::Window);
 
 
     playAction = new QAction(style()->standardIcon(QStyle::SP_MediaPlay), tr("Play"), ui->mainToolBar);
@@ -183,9 +184,9 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(showInfoWindowAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-    this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume"), ui->mainToolBar);
-    this->showToolBar2Action->setCheckable(true);
-    connect(showToolBar2Action, SIGNAL(triggered()), this, SLOT(showToolBar2Slot()));
+    this->showToolBar2Action  = new QAction(QIcon::fromTheme("general_speaker"), tr("Show Volume Control"), ui->mainToolBar);
+    //this->showToolBar2Action->setCheckable(true);
+    connect(this->showToolBar2Action, SIGNAL(triggered()), this, SLOT(showVolumeDialogSlot()));
 
 
     this->goHomeAction = new QAction(QIcon::fromTheme("general_device_root_folder"), tr("Go Home"), ui->mainToolBar);
@@ -208,15 +209,7 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     connect(nextAction, SIGNAL(triggered()), this, SLOT(showInfoWindowSlot()));
 
 
-    //this->addToolBarButtonsLandscape();
-
-
-
-
-    qDebug() << this->ui->mainToolBar->height();
-
-    //eq->show();
-    this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
+   // this->ui->volumePanel->layout()->addWidget(this->volumeSlider);
 
 
 
@@ -268,8 +261,10 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
 
 
     if(SymfonieDb::getInstance()->getSetting("is_show_main_toolbar", 1).toInt() == 1){
+        this->isMainToolbarVisible = true;
         this->ui->mainToolBar->show();
     }else{
+        this->isMainToolbarVisible = false;
         this->ui->mainToolBar->hide();
     }
 
@@ -285,13 +280,13 @@ MainWindow::MainWindow(const QApplication *app, SymfonieMediaPlayer* player, QWi
     int testOrientationMode = SymfonieDb::getInstance()->getSetting("orientation_mode", QVariant(Qt::WA_Maemo5LandscapeOrientation)).toInt();
 
     if(testOrientationMode == Qt::WA_Maemo5AutoOrientation){
-        //this->orientationAuto->trigger();
+        this->orientationAuto->trigger();
         setOrientationMode(Qt::WA_Maemo5AutoOrientation);
     }else if(testOrientationMode == Qt::WA_Maemo5PortraitOrientation){
-        //this->orientationPortrait->trigger();
+        this->orientationPortrait->trigger();
         setOrientationMode(Qt::WA_Maemo5PortraitOrientation);
     }else{
-        //this->orientationLandscape->trigger();
+        this->orientationLandscape->trigger();
         setOrientationMode(Qt::WA_Maemo5LandscapeOrientation);
     }
 
@@ -350,6 +345,10 @@ MainWindow::~MainWindow()
         delete this->optionsDialog;
     }
 
+    if(this->volumeDialog != NULL){
+        delete this->volumeDialog;
+    }
+
 
 }
 
@@ -357,6 +356,7 @@ MainWindow::~MainWindow()
 
 
 void MainWindow::setupToolBarButtonsLandscape(){
+
     this->ui->mainToolBar->clear();
     this->ui->mainToolBar->addAction(this->goHomeAction);
     this->ui->mainToolBar->addAction(this->goUpAction);
@@ -371,14 +371,22 @@ void MainWindow::setupToolBarButtonsLandscape(){
     //this->ui->mainToolBar->addAction(this->toggleFullScreenAction);
 
     this->ui->mainToolBar2->hide();
+    this->setToolbarVisibility(this->isMainToolbarVisible);
 }
 
 
 void MainWindow::setupToolBarButtonsPortrait(){
+
+
+
     this->ui->mainToolBar->clear();
     this->ui->mainToolBar2->clear();
 
 
+
+
+
+
     this->ui->mainToolBar2->addAction(prevAction);
     this->ui->mainToolBar2->addAction(playAction);
     this->ui->mainToolBar2->addAction(nextAction);
@@ -394,6 +402,7 @@ void MainWindow::setupToolBarButtonsPortrait(){
 
 
     this->ui->mainToolBar2->show();
+    this->setToolbarVisibility(this->isMainToolbarVisible);
 }
 
 
@@ -521,6 +530,27 @@ void MainWindow::showOptionsWindowSlot(){
     this->optionsDialog->exec();
 }
 
+void MainWindow::showVolumeDialogSlot(){
+    
+    if(this->volumeDialog == NULL){
+        this->volumeDialog = new SymfonieVolumeDialog(this);
+        this->volumeSlider = new SymfonieVolumeSlider(this->getPlayer()->getAudioOutput(), this);
+
+        this->volumeDialog->layout()->addWidget(this->volumeSlider);
+
+/*
+        connect(this->volumeDialog, SIGNAL(finished(int)),
+                this, SLOT(volumeDialogClosedSlot(int)));
+                */
+    }
+
+    this->volumeDialog->exec();
+}
+
+void MainWindow::volumeDialogClosedSlot(){
+
+}
+
 
 void MainWindow::setToolbarVisibility(bool isShow){
     if(isShow){
@@ -537,7 +567,8 @@ void MainWindow::setToolbarVisibility(bool isShow){
 }
 
 void MainWindow::optionsChangedSlot(int){
-    this->setToolbarVisibility(this->optionsDialog->getOptionIsShowToolbar());
+    this->isMainToolbarVisible = this->optionsDialog->getOptionIsShowToolbar();
+    this->setToolbarVisibility(this->isMainToolbarVisible);
 }
 
 
@@ -642,13 +673,15 @@ void MainWindow::goToCurDirSlot(){
 
 void MainWindow::playerTickSlot(qint64 time)
 {
+
     if(this->ui->sliderPanel->isVisible()){
         QTime displayTime(0, (time / 60000) % 60, (time / 1000) % 60);
         int tt = this->getPlayer()->getMediaObject()->totalTime();
         QTime totalTime(0, (tt / 60000) % 60, (tt / 1000) % 60);
-        this->ui->sliderLabel->setText(displayTime.toString("mm:ss") + "/" + totalTime.toString("mm:ss"));
+        this->seekSlider->setText(displayTime.toString("mm:ss") + "/" + totalTime.toString("mm:ss"));
 
     }
+
 }
 
 SymfoniePlayList* MainWindow::createHomePlayList(){
@@ -717,11 +750,11 @@ void MainWindow::goHomeSlot(){
 void MainWindow::showInfoWindowSlot(){
     if(this->ui->sliderPanel->isVisible()){
         this->ui->sliderPanel->hide();
-        this->ui->sliderLabel->hide();
+
         this->showInfoWindowAction->setChecked(false);
     }else{
         this->ui->sliderPanel->show();
-        this->ui->sliderLabel->show();
+
         this->showInfoWindowAction->setChecked(true);
     }
 
