@@ -1,4 +1,4 @@
-/opt/qt4-maemo5/bin/qmake symfonie.pro
+/usr/bin/qmake symfonie.pro
 #make clean
 make
 run-standalone.sh ./symfonie
