@@ -12,6 +12,10 @@
 #include "symfonieplaylist.h"
 
 
+
+
+
+class QStringList;
 class QTimer;
 
 class SymfonieMediaPlayer : public QObject
@@ -37,7 +41,9 @@ public:
     void setPlayList(SymfoniePlayList*);
     Phonon::AudioOutput* getAudioOutput();
 
-    void init();
+    bool insertEqualizerEffect();
+    void removeEqualizerEffect();
+
     bool isCanPlay();
     QString getFilePathAt(int index);
     void fetchSongInfo(QString path);
@@ -54,27 +60,37 @@ public:
     void doTimer(int time);
     void stopTimer();
     int getTimerRemain();
+    void setFileFilter(QStringList filterList);
+
+
+
+    void startGraduateVolumeResuming(qreal value);
 
 
 
 
 
 Q_SIGNALS:
-     void directoryChangedSignal(QString);
-     void scanDirCompletedSignal(SymfoniePlayList*, QString);
-     void mediaStateChangedSignal( Phonon::State newstate, Phonon::State oldstate);
-     void playListUpdatedSignal(SymfoniePlayList* playList);
-     void timerStoppedSignal();
-     void timerRemainTimeChangedSignal(int);
+    void directoryChangedSignal(QString);
+    void scanDirCompletedSignal(SymfoniePlayList*, QString);
+    void mediaStateChangedSignal( Phonon::State newstate, Phonon::State oldstate);
+    void playListUpdatedSignal(SymfoniePlayList* playList);
+    void timerStoppedSignal();
+    void timerRemainTimeChangedSignal(int);
+
+    void equalizerEffectInsertedSignal();
+    void equalizerEffectRemovedSignal();
 
 
 public Q_SLOTS:
-     void mediaStateChangedSlot( Phonon::State newstate, Phonon::State oldstate);
-     void aboutToFinishSlot();
-     void currentSourceChangedSlot ( const Phonon::MediaSource & newSource );
-     void playListUpdatedSlot(SymfoniePlayList* playList);
-     void oneCompletedSlot();
-     void timerEndSlot();
+    void mediaStateChangedSlot( Phonon::State newstate, Phonon::State oldstate);
+    void aboutToFinishSlot();
+    void currentSourceChangedSlot ( const Phonon::MediaSource & newSource );
+    void playListUpdatedSlot(SymfoniePlayList* playList);
+    void oneCompletedSlot();
+    void timerEndSlot();
+    void doGraduateVolumeResuming();
+
 
 
 
@@ -83,7 +99,7 @@ private Q_SLOTS:
 
 
 protected:
-      void setCurrentDirectory(QString dir);
+    void setCurrentDirectory(QString dir);
 
 
 private:
@@ -91,6 +107,10 @@ private:
     Phonon::AudioOutput *audioOutput;
     Phonon::Path path;
     Phonon::Effect *equalizerEffect;
+    bool hasEqualizerEffect;
+    bool isEqualizerEnabled;
+
+    void initPlayer();
 
     QString currentDirectory;
     SymfoniePlayList *playList;
@@ -103,7 +123,16 @@ private:
 
     int timerRemainCounter; //why do I need to implement this?
 
- static const int TIMER_VALUE_UPDATE_RATE = 3000; //msec
+    static const int TIMER_VALUE_UPDATE_RATE = 3000; //msec
+
+
+    QStringList fileFilterList;
+
+    static const qreal GRADUATE_VOLUME_INCREMENT = .02; //1 sec
+    QTimer *graduateVolumeTimer;
+    qreal graduateVolumeResumeTo;
+
+
 
 
 
